==> qtjambi-datavisualization-6.5.7-sources.jar: io/qt/datavis/QTouch3DInputHandler.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Basic touch display based input handler</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qtouch3dinputhandler.html">QTouch3DInputHandler</a></code></p>
 * <p>This class was introduced in Qt QtDataVisualization 1.0.</p>
 */
public class QTouch3DInputHandler extends io.qt.datavis.Q3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTouch3DInputHandler.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qtouch3dinputhandler.html#QTouch3DInputHandler">QTouch3DInputHandler::<wbr/>QTouch3DInputHandler(QObject*)</a></code></p>
     */
    public QTouch3DInputHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTouch3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#touchEvent">QAbstract3DInputHandler::<wbr/>touchEvent(QTouchEvent*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public void touchEvent(io.qt.gui.@Nullable QTouchEvent event){
        touchEvent_native_QTouchEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native void touchEvent_native_QTouchEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTouch3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QTouch3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTouch3DInputHandler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTouch3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTouch3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
}

==> qtjambi-datavisualization-6.6.0-sources.jar: io/qt/datavis/QTouch3DInputHandler.java <==
package io.qt.datavis;

import io.qt.*;


/**
 * <p>Basic touch display based input handler</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qtouch3dinputhandler.html">QTouch3DInputHandler</a></code></p>
 */
public class QTouch3DInputHandler extends io.qt.datavis.Q3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTouch3DInputHandler.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qtouch3dinputhandler.html#QTouch3DInputHandler">QTouch3DInputHandler::<wbr>QTouch3DInputHandler(QObject*)</a></code></p>
     */
    public QTouch3DInputHandler(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTouch3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#touchEvent">QAbstract3DInputHandler::<wbr>touchEvent(QTouchEvent*)</a></code></p>
     */
    @QtUninvokable
    @Override
    public void touchEvent(io.qt.gui.@Nullable QTouchEvent event){
        touchEvent_native_QTouchEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native void touchEvent_native_QTouchEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTouch3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTouch3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTouch3DInputHandler instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTouch3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTouch3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
}
